Welcome to ClientVPS Mirrors

Help for package ROI.plugin.symphony
Version: 1.0-0
Title: 'SYMPHONY' Plug-in for the 'R' Optimization Interface
Description: Enhances the R Optimization Infrastructure ('ROI') package by registering the 'SYMPHONY' open-source solver from the COIN-OR suite. It allows for solving mixed integer linear programming (MILP) problems as well as all variants/combinations of LP, IP.
Imports: methods, ROI (≥ 0.3-0), Rsymphony, slam
License: GPL-3
URL: http://roi.r-forge.r-project.org/, https://r-forge.r-project.org/projects/roi/
NeedsCompilation: no
Packaged: 2020-08-30 18:25:51 UTC; f
Author: Stefan Theussl [aut, cre]
Maintainer: Stefan Theussl <Stefan.Theussl@R-Project.org>
Repository: CRAN
Date/Publication: 2020-08-31 11:40:02 UTC

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.